
/* stores if a row was filtered by name */
var filteredList = [];

/* stores if the table is currently filtered by link */
var filtered = false;


/* This function filters the table's rows by name. The user types some text into the input and if any part of that text does not match the text in column 2 of the table (the name column), then that row will have its display hidden. The input text is not case sensitive */
function filterByName()
{
  /* gets the text and list of all rows in the table. The text is changed to lowercase for case insensitivity purposes. */
  var inputText = document.getElementById("nameFilter").value.toLowerCase();
  var table = document.getElementById("filterTable");
  var rows = table.getElementsByTagName("tr");

  /* used for parsing the text in the table */
  var playerElement, playerText;

  /* for every row */
  for (var i = 0; i < rows.length; i++)
  {
    /* if the element in column 1 is not null */
    if (playerElement = rows[i].getElementsByTagName("td")[1])
    {
      /* get the text from the table data element and change it to lowercase*/
      playerText = playerElement.textContent.toLowerCase();

      /* compare the input text with the text in the table. If any part of it does not match, then set the display of this row to none. */
      if (playerText.indexOf(inputText) > -1)
      {
        rows[i].style.display = "";
        filteredList[i] = false;
      }
      else
      {
        rows[i].style.display = "none";
        filteredList[i] = true;
      }
    }
  }
  /* if the list is also filtered by link, call the helper function to re-filter */
  if (filtered)
    filterByLinkAndName();
}


/* This function toggles the display of the rows of the table without links when a button is pressed. The functinoality is similar to filterByName() */
function filterByLink()
{
  /* get all of the rows in the table and the button element */
  var table = document.getElementById("filterTable");
  var rows = table.getElementsByTagName("tr");
  var btnText = document.getElementById("linkFilter");
  
  /* used for parsing the text in the table */
  var linkElement, linkText;
  
  /* if the table is currently filtered, de-filter it */
  if (filtered)
  {
    /* table is no longer filtered */
    filtered = false;
    /* change the button text */
    btnText.innerHTML = "Filter: Links";
    
    /* set the display of all rows to be visible */
    for (var i = 0; i < rows.length; i++)
    {
      rows[i].style.display = "";
    }
    
    /* Filter the table by name to make sure everything is correct */
    filterByName();
  }
  /* if the table is not filtered, filter it */
  else
  {
    /* change the button text */
    btnText.innerHTML = "Filter: All";
    
    /* Filter the table by name to make sure everything is correct */
    filterByName();
    
    /* set the display of rows with no text in their 6th column to be none */
    for (var i = 0; i < rows.length; i++)
    {
      if (linkElement = rows[i].getElementsByTagName("td")[5])
      {
        linkText = linkElement.textContent.toLowerCase();
        
        /* display is none if there is no link. Only change the display of rows that are not already filtered by name*/
        if (!filteredList[i])
          rows[i].style.display = (linkText === "" || linkText === "...") ? "none" : "";
      }
    }
    /* table is now filtered */
    filtered = true;
  }
}

/* This function is called by the filterByName function when the table is filtered by link. It refilters the table to make sure the correct rows are visible. Functionality is the same as in the filterByName function except the button text is not changed and the filtered global variable is not changed */
function filterByLinkAndName ()
{
  var table = document.getElementById("filterTable");
  var rows = table.getElementsByTagName("tr");
  
  var linkElement, linkText;
  
  for (var i = 0; i < rows.length; i++)
  {
    if (linkElement = rows[i].getElementsByTagName("td")[5])
    {
      linkText = linkElement.textContent.toLowerCase();
      if (!filteredList[i])
        rows[i].style.display = (linkText === "" || linkText === "...") ? "none" : "";
    }
  }
}
